package com.ximai.mes.md.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ximai.mes.md.domain.MdSapField;
import com.ximai.mes.md.vo.SapFieldVo;

import java.util.List;
import java.util.Map;


/**
 * Sap特性视图Mapper接口
 *
 * @author generator
 * @date 2024-01-31
 */
public interface MdSapFieldMapper extends BaseMapper<MdSapField> {

    List<MdSapField> listByMap(Map<String, Object> params);

    Integer countByMap(Map<String, Object> params);

    List<SapFieldVo> listVoByParentId(Map<String, Object> params);

    Boolean updateParentIdByIds(MdSapField mdSapField);
}
